[gnumeric] Introspection fixes.



commit 3b03ca2ee2c581cd303c476dfe763d7edecdd793
Author: Morten Welinder <terra gnome org>
Date:   Tue Apr 24 19:42:54 2018 -0400

    Introspection fixes.
    
    Specifically, avoid annotations that crash the scanner.  *sigh*

 OChangeLog-2000-02-23          |    2 +-
 OChangeLog-2001-06-26          |    2 +-
 OChangeLog-2003-12-23          |    2 +-
 plugins/excel/ms-excel-read.c  |    2 +-
 plugins/excel/ms-excel-write.c |    2 +-
 src/colrow.c                   |   24 +++++++++++++-----------
 src/colrow.h                   |    2 +-
 src/commands.c                 |    4 ++--
 src/sheet.c                    |   12 ++++++------
 src/wbc-gtk-edit.c             |    2 +-
 10 files changed, 28 insertions(+), 26 deletions(-)
---
diff --git a/OChangeLog-2000-02-23 b/OChangeLog-2000-02-23
index 8806a2c..aaf0a8a 100644
--- a/OChangeLog-2000-02-23
+++ b/OChangeLog-2000-02-23
@@ -1657,7 +1657,7 @@ Sun Jan 30 15:40:50 EST 2000 Gregory McLean <gregm comstar net>
 
        * src/gnumeric-sheet.h (GnumericSheet) : Remove unused member item_bar_col.
 
-       * src/colrow.c (col_row_set_visiblity) : Use sheet_redraw_headers
+       * src/colrow.c (col_row_set_visibility) : Use sheet_redraw_headers
          in place of sheet_redraw_{cols,row}.
        * src/selection.c (sheet_selection_append_range) : Ditto.
        (sheet_select_all) : Ditto.
diff --git a/OChangeLog-2001-06-26 b/OChangeLog-2001-06-26
index 183fc66..8bbb19b 100644
--- a/OChangeLog-2001-06-26
+++ b/OChangeLog-2001-06-26
@@ -2545,7 +2545,7 @@
          adaptive precision but I am lazy.
        (format_number) : add fractions.
 
-       * src/commands.c (cmd_autofill_redo) : changing visiblity can triger a
+       * src/commands.c (cmd_autofill_redo) : changing visibility can triger a
          draw which requiresthat things be rendered and spanned.  Be sure to
          complete the action BEFORE changing visibility.
 
diff --git a/OChangeLog-2003-12-23 b/OChangeLog-2003-12-23
index b14f8cb..e82814d 100644
--- a/OChangeLog-2003-12-23
+++ b/OChangeLog-2003-12-23
@@ -8521,7 +8521,7 @@
 
        * src/colrow.c (cb_colrow_visibility) : selections are now part of
          sheetview.
-       (colrow_get_visiblity_toggle) : ditto.
+       (colrow_get_visibility_toggle) : ditto.
 
        * src/cmd-edit.c (cmd_select_cur_row) : convert to sheetview.
        (cmd_select_cur_col) : ditto.
diff --git a/plugins/excel/ms-excel-read.c b/plugins/excel/ms-excel-read.c
index f802fdd..1369961 100644
--- a/plugins/excel/ms-excel-read.c
+++ b/plugins/excel/ms-excel-read.c
@@ -1489,7 +1489,7 @@ excel_read_BOUNDSHEET (BiffQuery *q, GnmXLImporter *importer)
                        g_printerr ("Unknown BIFF Boundsheet spec. Assuming same as Biff7 FIXME\n");
                bs->streamStartPos = GSF_LE_GET_GUINT32 (q->non_decrypted_data);
 
-               /* NOTE : MS Docs appear wrong.  It is visiblity _then_ type */
+               /* NOTE : MS Docs appear wrong.  It is visibility _then_ type */
                switch (GSF_LE_GET_GUINT8 (q->data + 5)) {
                case 0: bs->type = MS_BIFF_TYPE_Worksheet;
                        default_name = _("Sheet%d");
diff --git a/plugins/excel/ms-excel-write.c b/plugins/excel/ms-excel-write.c
index d25255f..71a63c2 100644
--- a/plugins/excel/ms-excel-write.c
+++ b/plugins/excel/ms-excel-write.c
@@ -1955,7 +1955,7 @@ excel_write_BOUNDSHEET (BiffPut *bp, Sheet *sheet)
 
        GSF_LE_SET_GUINT32 (data, 0xdeadbeef); /* To be stream start pos */
 
-       /* NOTE : MS Docs appear wrong.  It is visiblity _then_ type */
+       /* NOTE : MS Docs appear wrong.  It is visibility _then_ type */
        GSF_LE_SET_GUINT8 (data+4, sheet->visibility);
 
        switch (sheet->sheet_type) {
diff --git a/src/colrow.c b/src/colrow.c
index dca6f48..f4e5d8d 100644
--- a/src/colrow.c
+++ b/src/colrow.c
@@ -1005,7 +1005,7 @@ typedef struct
 {
        gboolean is_cols, visible;
        ColRowVisList *elements;
-} ColRowVisiblity;
+} ColRowVisibility;
 
 static gint
 colrow_index_cmp (ColRowIndex const *a, ColRowIndex const *b)
@@ -1015,7 +1015,7 @@ colrow_index_cmp (ColRowIndex const *a, ColRowIndex const *b)
 }
 
 static void
-colrow_visibility (Sheet const *sheet, ColRowVisiblity * const dat,
+colrow_visibility (Sheet const *sheet, ColRowVisibility * const dat,
                   int first, int last)
 {
        int i;
@@ -1080,7 +1080,7 @@ ColRowVisList *
 colrow_get_outline_toggle (Sheet const *sheet, gboolean is_cols, gboolean visible,
                           int first, int last)
 {
-       ColRowVisiblity closure;
+       ColRowVisibility closure;
        closure.is_cols = is_cols;
        closure.visible = visible;
        closure.elements = NULL;
@@ -1092,7 +1092,7 @@ colrow_get_outline_toggle (Sheet const *sheet, gboolean is_cols, gboolean visibl
 static void
 cb_colrow_visibility (SheetView *sv, GnmRange const *r, gpointer closure)
 {
-       ColRowVisiblity * const dat = (ColRowVisiblity *)closure;
+       ColRowVisibility * const dat = (ColRowVisibility *)closure;
        int first, last;
 
        if (dat->is_cols) {
@@ -1106,7 +1106,7 @@ cb_colrow_visibility (SheetView *sv, GnmRange const *r, gpointer closure)
 }
 
 /**
- * colrow_get_visiblity_toggle: (skip)
+ * colrow_get_visibility_toggle: (skip)
  * @sv: The sheet view whose selection we are interested in.
  * @is_cols: %TRUE for columns, %FALSE for rows.
  * @visible: Should we unhide or hide the cols/rows.
@@ -1117,10 +1117,10 @@ cb_colrow_visibility (SheetView *sv, GnmRange const *r, gpointer closure)
  * Returns: (transfer full): the list.
  */
 ColRowVisList *
-colrow_get_visiblity_toggle (SheetView *sv, gboolean is_cols,
+colrow_get_visibility_toggle (SheetView *sv, gboolean is_cols,
                             gboolean visible)
 {
-       ColRowVisiblity closure;
+       ColRowVisibility closure;
        closure.is_cols = is_cols;
        closure.visible = visible;
        closure.elements = NULL;
@@ -1307,7 +1307,9 @@ colrow_set_visibility (Sheet *sheet, gboolean is_cols,
        }
 }
 
-/**
+// Introspection scanner crashes if the following "hide" is removed.
+
+/*hide*
  * colrow_get_global_outline: (skip)
  * @sheet:
  * @is_cols: %TRUE for columns, %FALSE for rows.
@@ -1315,8 +1317,8 @@ colrow_set_visibility (Sheet *sheet, gboolean is_cols,
  * @show: (out):
  * @hide: (out):
  *
- * Collect the set of visiblity changes required to change the visiblity of
- * all outlined columns such tach those > @depth are visible.
+ * Collect the set of visibility changes required to change the visibility of
+ * all outlined columns such that those > @depth are visible.
  **/
 void
 colrow_get_global_outline (Sheet const *sheet, gboolean is_cols, int depth,
@@ -1341,7 +1343,7 @@ colrow_get_global_outline (Sheet const *sheet, gboolean is_cols, int depth,
 
                /* see what sort of changes are necessary and do simple run
                 * length encoding.  Do not be too efficent, we need to change
-                * the visiblity per outline level or the collapse state
+                * the visibility per outline level or the collapse state
                 * change in colrow_set_visibility is missed. */
                if (cri->outline_level < depth) {
                        if (cri->visible)
diff --git a/src/colrow.h b/src/colrow.h
index f8c9593..126744a 100644
--- a/src/colrow.h
+++ b/src/colrow.h
@@ -134,7 +134,7 @@ int          colrow_find_outline_bound      (Sheet const *sheet, gboolean is_cols,
                                                 int index, int depth, gboolean inc);
 ColRowVisList  *colrow_get_outline_toggle      (Sheet const *sheet, gboolean is_cols,
                                                 gboolean visible, int first, int last);
-ColRowVisList  *colrow_get_visiblity_toggle    (SheetView *sv, gboolean is_cols,
+ColRowVisList  *colrow_get_visibility_toggle   (SheetView *sv, gboolean is_cols,
                                                 gboolean visible);
 void            colrow_set_visibility          (Sheet *sheet, gboolean is_cols,
                                                 gboolean visible, int first, int last);
diff --git a/src/commands.c b/src/commands.c
index d5788f9..b289cd2 100644
--- a/src/commands.c
+++ b/src/commands.c
@@ -2323,9 +2323,9 @@ cmd_selection_colrow_hide (WorkbookControl *wbc,
        GSList *show = NULL, *hide = NULL;
 
        if (visible)
-               show = colrow_get_visiblity_toggle (sv, is_cols, TRUE);
+               show = colrow_get_visibility_toggle (sv, is_cols, TRUE);
        else
-               hide = colrow_get_visiblity_toggle (sv, is_cols, FALSE);
+               hide = colrow_get_visibility_toggle (sv, is_cols, FALSE);
        n = colrow_vis_list_length (hide) + colrow_vis_list_length (show);
        sheet = sv_sheet (sv);
 
diff --git a/src/wbc-gtk-edit.c b/src/wbc-gtk-edit.c
index 1e12d65..861c79a 100644
--- a/src/wbc-gtk-edit.c
+++ b/src/wbc-gtk-edit.c
@@ -1060,7 +1060,7 @@ wbcg_insert_object (WBCGtk *wbcg, SheetObject *so)
  *
  * If we are preparing to insert a new object, unref the object, and restore
  * a normal state to the scgs that was changed in wbcg_insert_object
- * (e.g.  visiblity of cursors)
+ * (e.g., visibility of cursors)
  **/
 void
 wbcg_insert_object_clear (WBCGtk *wbcg)


[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/sheet.c b/src/sheet.c
index 53135c5..410ede7 100644
--- a/src/sheet.c
+++ b/src/sheet.c
@@ -3997,7 +3997,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
 {
        GnmValue *cont;
        GnmCellIter iter;
-       gboolean const visiblity_matters = (flags & CELL_ITER_IGNORE_HIDDEN) != 0;
+       gboolean const visibility_matters = (flags & CELL_ITER_IGNORE_HIDDEN) != 0;
        gboolean const ignore_filtered = (flags & CELL_ITER_IGNORE_FILTERED) != 0;
        gboolean const only_existing = (flags & CELL_ITER_IGNORE_NONEXISTENT) != 0;
        gboolean const ignore_empty = (flags & CELL_ITER_IGNORE_EMPTY) != 0;
@@ -4054,7 +4054,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
                                last_row = iter.pp.eval.row;
                                iter.ri = sheet_row_get (iter.pp.sheet, last_row);
                        }
-                       if (visiblity_matters && !iter.ri->visible)
+                       if (visibility_matters && !iter.ri->visible)
                                continue;
                        if (ignore_filtered && iter.ri->in_filter && !iter.ri->visible)
                                continue;
@@ -4063,7 +4063,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
                                last_col = iter.pp.eval.col;
                                iter.ci = sheet_col_get (iter.pp.sheet, last_col);
                        }
-                       if (visiblity_matters && !iter.ci->visible)
+                       if (visibility_matters && !iter.ci->visible)
                                continue;
 
                        ignore = (ignore_empty &&
@@ -4086,7 +4086,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
             ++iter.pp.eval.row) {
                iter.ri = sheet_row_get (iter.pp.sheet, iter.pp.eval.row);
 
                /* no need to check visiblity, that would require a colinfo to exist */
                if (iter.ri == NULL) {
                        if (only_existing) {
                                /* skip segments with no cells */
@@ -4108,7 +4108,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
                        continue;
                }
 
-               if (visiblity_matters && !iter.ri->visible)
+               if (visibility_matters && !iter.ri->visible)
                        continue;
                if (ignore_filtered && iter.ri->in_filter && !iter.ri->visible)
                        continue;
@@ -4116,7 +4116,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
                for (iter.pp.eval.col = start_col; iter.pp.eval.col <= end_col; ++iter.pp.eval.col) {
                        iter.ci = sheet_col_get (sheet, iter.pp.eval.col);
                        if (iter.ci != NULL) {
-                               if (visiblity_matters && !iter.ci->visible)
+                               if (visibility_matters && !iter.ci->visible)
                                        continue;
                                iter.cell = sheet_cell_get (sheet,
                                        iter.pp.eval.col, iter.pp.eval.row);
@@ -4086,7 +4086,7 @@ sheet_foreach_cell_in_range (Sheet *sheet, CellIterFlags flags,
                iter.ri = sheet_row_get (iter.pp.sheet, iter.pp.eval.row);
 
-               /* no need to check visiblity, that would require a colinfo to exist */
+               /* no need to check visibility, that would require a colinfo to exist */
                if (iter.ri == NULL) {
                        if (only_existing) {